@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: FontFile.pm,v 1.11 2004/12/29 01:12:27 fredo Exp $
+#   $Id: FontFile.pm,v 1.13 2005/03/14 22:01:27 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::CIDFont::TrueType::FontFile;
@@ -49,7 +49,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Basic::PDF::Dict );
 
-    ( $VERSION ) = '$Revision: 1.11 $' =~ /Revision: (\S+)\s/; # $Date: 2004/12/29 01:12:27 $
+    ( $VERSION ) = '$Revision: 1.13 $' =~ /Revision: (\S+)\s/; # $Date: 2005/03/14 22:01:27 $
     $cmap={};
 }
 no warnings qw[ recursion uninitialized ];
@@ -606,7 +606,7 @@ sub outobjdeep {
         $f->{'CFF '}->read_dat;
         $self->{' stream'} = $f->{'CFF '}->{' dat'};
     } else {
-        if ($self->data->{subset}) {
+        if ($self->data->{subset} && !$self->data->{nosubset}) {
             $f->{'glyf'}->read;
             for (my $i = 0; $i < $self->glyphNum; $i++) {
                 next if($self->subvec($i));
@@ -636,6 +636,12 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: FontFile.pm,v $
+    Revision 1.13  2005/03/14 22:01:27  fredo
+    upd 2005
+
+    Revision 1.12  2005/01/21 10:00:43  fredo
+    added handling of nosubset option
+
     Revision 1.11  2004/12/29 01:12:27  fredo
     fixed no warn for recursion
 
