@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Separation.pm,v 1.7 2004/12/16 00:30:53 fredo Exp $
+#   $Id: Separation.pm,v 1.8 2005/03/14 22:01:27 fredo Exp $
 #
 #=======================================================================
 
@@ -43,7 +43,7 @@ BEGIN {
     use Math::Trig;
 
     @ISA = qw( PDF::API2::Resource::ColorSpace );
-    ( $VERSION ) = '$Revision: 1.7 $' =~ /Revision: (\S+)\s/; # $Date: 2004/12/16 00:30:53 $
+    ( $VERSION ) = '$Revision: 1.8 $' =~ /Revision: (\S+)\s/; # $Date: 2005/03/14 22:01:27 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -194,6 +194,9 @@ __END__
 =head1 HISTORY
 
     $Log: Separation.pm,v $
+    Revision 1.8  2005/03/14 22:01:27  fredo
+    upd 2005
+
     Revision 1.7  2004/12/16 00:30:53  fredo
     added no warn for recursion
 
