@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: GIF.pm,v 1.7 2004/06/15 09:14:54 fredo Exp $
+#   $Id: GIF.pm,v 1.9 2005/03/14 22:01:31 fredo Exp $
 #
 #=======================================================================
 
@@ -44,9 +44,10 @@ BEGIN {
     use vars qw(@ISA $VERSION);
     @ISA = qw( PDF::API2::Resource::XObject::Image );
 
-    ( $VERSION ) = '$Revision: 1.7 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/15 09:14:54 $
+    ( $VERSION ) = '$Revision: 1.9 $' =~ /Revision: (\S+)\s/; # $Date: 2005/03/14 22:01:31 $
 
 }
+no warnings qw[ deprecated recursion uninitialized ];
 
 =item $res = PDF::API2::Resource::XObject::Image::GIF->new $pdf, $file [, $name]
 
@@ -286,6 +287,12 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: GIF.pm,v $
+    Revision 1.9  2005/03/14 22:01:31  fredo
+    upd 2005
+
+    Revision 1.8  2004/12/16 00:30:55  fredo
+    added no warn for recursion
+
     Revision 1.7  2004/06/15 09:14:54  fredo
     removed cr+lf
 
